OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Zaznamki",
    "Failed to import one bookmark, because: " : "Uvoz izbranega zaznamka je spodletel:",
    "No file provided for import" : "Ni navedenih datotek za uvoz",
    "Unsupported file type for import" : "Nepodprta vrsta datoteke za uvoz",
    "Add a Bookmark" : "Dodaj zaznamek",
    "Select" : "Izbor",
    "Deselect" : "Odstrani izbor",
    "Details" : "Podrobnosti",
    "Delete" : "Izbriši",
    "Saved" : "Shranjeno",
    "Tags" : "Oznake",
    "Description" : "Opis",
    "No bookmarks here." : "Ni še dodanih zaznamkov.",
    "Settings" : "Nastavitve",
    "Add to {instanceName} " : "Dodaj {instanceName} ",
    "Recently added" : "Nedavno dodano",
    "Most visited" : "Najpogosteje obiskano",
    "RSS Feed" : "Vir RSS",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Trajno odstrani vse zaznamke, povezane z računom. Dejanja ni mogoče povrniti!",
    "Delete all bookmarks" : "Izbriši vse zaznamke",
    "Open details" : "Odpri podrobnosti",
    "An error occurred while trying to save the bookmark." : "Prišlo je do napake med shranjevanjem zaznamka.",
    "Error" : "Napaka",
    "Import error" : "Napaka uvoza",
    "Import completed successfully." : "Uvoz je uspešno končan.",
    "Set tags" : "Nastavitve oznak",
    "A Bookmark manager for Nextcloud" : "Upravljalnik zaznamkov za Nextcloud",
    "Add a bookmark" : "Dodaj zaznamek",
    "This URL is already bookmarked! Overwrite?" : "Ta naslov URL je že dodan med zaznamke. Ali ga želite prepisati?",
    "The title of the page" : "Naziv strani",
    "The address of the page" : "Naslov strani",
    "Description of the page" : "Opis strani",
    "Save" : "Shrani",
    "Previews" : "Predogledi",
    "Screenly API URL" : "Naslov URL za API Screenly",
    "Screenly API key" : "Ključ za API Screenly",
    "Bookmarks feed" : "Vir zaznamkov"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
